searchData={"items":[{"type":"module","title":"MaxoAdapt.Config","doc":"","ref":"MaxoAdapt.Config.html"},{"type":"function","title":"MaxoAdapt.Config.debug/0","doc":"","ref":"MaxoAdapt.Config.html#debug/0"},{"type":"function","title":"MaxoAdapt.Config.default_mode/0","doc":"","ref":"MaxoAdapt.Config.html#default_mode/0"},{"type":"module","title":"MaxoAdapt.Log","doc":"","ref":"MaxoAdapt.Log.html"},{"type":"function","title":"MaxoAdapt.Log.inspect/2","doc":"","ref":"MaxoAdapt.Log.html#inspect/2"},{"type":"function","title":"MaxoAdapt.Log.inspect_ast/2","doc":"","ref":"MaxoAdapt.Log.html#inspect_ast/2"},{"type":"module","title":"MaxoAdapt.ProcDict","doc":"Custom wrapper around process dictionary, that supports looking up values from ancestor processes\nThe cost of walking the process tree is paid only on first miss, subsequent calls are cached in the\nlocal process dictionary.\n\nPrimary use case is testing different implementation concurrently, with each test case having it's\nown configured adapter (and not affecting other test cases).\n\nThe walking up the process tree ensures that we get proper results even if we start subprocesses,\nthat do not share our process dictionary.\n\nUsed for `:get_dict` strategy.","ref":"MaxoAdapt.ProcDict.html"},{"type":"function","title":"MaxoAdapt.ProcDict.get_with_ancestors/1","doc":"","ref":"MaxoAdapt.ProcDict.html#get_with_ancestors/1"},{"type":"function","title":"MaxoAdapt.ProcDict.get_with_ancestors/2","doc":"","ref":"MaxoAdapt.ProcDict.html#get_with_ancestors/2"},{"type":"function","title":"MaxoAdapt.ProcDict.put/2","doc":"","ref":"MaxoAdapt.ProcDict.html#put/2"},{"type":"extras","title":"MaxoAdapt","doc":"# MaxoAdapt\n\n[![CI](https://github.com/maxohq/maxo_adapt/actions/workflows/ci.yml/badge.svg?style=flat)](https://github.com/maxohq/maxo_adapt/actions/workflows/ci.yml)\n[![Hex.pm](https://img.shields.io/hexpm/v/maxo_adapt.svg?style=flat)](https://hex.pm/packages/maxo_adapt)\n[![Docs](https://img.shields.io/badge/hex-docs-lightgreen.svg?style=flat)](https://hexdocs.pm/maxo_adapt)\n[![Total Download](https://img.shields.io/hexpm/dt/maxo_adapt.svg?style=flat)](https://hex.pm/packages/maxo_adapt)\n[![License](https://img.shields.io/hexpm/l/maxo_adapt.svg?style=flat)](https://github.com/maxohq/maxo_adapt/blob/main/LICENCE)\n\n`MaxoAdapt` is a fork from https://github.com/IanLuites/adapter with updates / fixes.\n\n---\n\nFast adapters with clear syntax and build-in safety.","ref":"readme.html"},{"type":"extras","title":"Why use MaxoAdapt? - MaxoAdapt","doc":"- Fast _(as fast as hardcoded `defdelegate`s)_\n- Easy _(define a behaviour and it takes care of everything else)_\n- Safe _(will error if the implementation does not match the behaviour)_\n- Clean _(clearly separated marked behaviour/delegate versus functions)_\n- Flexible _(change implementation/adapter at runtime)_\n\nIn addition to these basic qualities it is:\n\n- Compatible and tested with releases (`distillery`, `mix release`)\n- Documentation compatible _(each stub copies the documentation of the `@callback`)_\n- Spec / Dialyzer _(each stub has a spec matching the `@callback`)_\n- IDE (intelligent code completion / intellisense) compatible [stubs]","ref":"readme.html#why-use-maxoadapt"},{"type":"extras","title":"Guides - MaxoAdapt","doc":"- [Intro](https://github.com/maxohq/maxo_adapt/tree/main/guides/intro.md)\n- [Configuration](https://github.com/maxohq/maxo_adapt/tree/main/guides/configuration.md)\n- [Debugging](https://github.com/maxohq/maxo_adapt/tree/main/guides/debugging.md)","ref":"readme.html#guides"},{"type":"extras","title":"Quick start - MaxoAdapt","doc":"```elixir\ndef deps do\n  [\n    {:maxo_adapt, \"~> 0.1\"}\n  ]\nend\n```\n\n```elixir\ndefmodule SessionRepo do\n  use MaxoAdapt\n\n  # Define the adapter behaviour\n  behaviour do\n    @doc ~S\"\"\"\n    Lookup a sessions based on token.\n    \"\"\"\n    @callback get(token :: binary) :: {:ok, Session.t | nil} | {:error, atom}\n  end\n\n  # Add module functions outside the behaviour definition\n  # These can use the behaviour's callbacks like they exist as functions.\n  @spec get!(binary) :: Session.t | nil | no_return\n  def get!(token) do\n    case get(token) do\n      {:ok, result} -> result\n      {:error, reason} -> raise \"SessionRepo: #{reason}\"\n    end\n  end\nend\n\n# PostgreSQL implementation\ndefmodule SessionRepo.PostgreSQL do\n  @behaviour SessionRepo\n\n  @impl SessionRepo\n  def get(token), do: {:ok, {token, :psql}}\nend\n\n# Redis implementation\ndefmodule SessionRepo.Redis do\n  @behaviour SessionRepo\n\n  @impl SessionRepo\n  def get(token), do: {:ok, {token, :redis}}\nend\n\n# Now configure\nSessionRepo.configure(SessionRepo.PostgreSQL)\n\n# Runtime switching possible\nSessionRepo.configure(SessionRepo.Redis)\n```\n\nThe docs can be found at  .","ref":"readme.html#quick-start"},{"type":"extras","title":"Support - MaxoAdapt","doc":"","ref":"readme.html#support"},{"type":"extras","title":"License - MaxoAdapt","doc":"The lib is available as open source under the terms of the [MIT License](https://opensource.org/licenses/MIT).","ref":"readme.html#license"}],"content_type":"text/markdown"}